@@ -1,3 +1,21 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'cgi'
 
@@ -19,6 +37,7 @@ end
           [ "Status", "status", true, "StatusHandler"],
           [ "Startup", "status/startup", false, "StartupStatusHandler"],
           [ "Profile", "status/profile", false, "ProfileStatusHandler"],
+          [ "Backup", "status/backup", false, "BackupStatusHandler"],
           [ "Log", "status/log", false, "LogStatusHandler"],
           [ "Debug", "status/debug", false, "DebugStatusHandler"],
           
@@ -28,6 +47,7 @@ end
           [ "Digipeater", "setup/digipeater", false, "DigipeaterSetupHandler"], 
           [ "Weather", "setup/weather", false, "WeatherSetupHandler"],
           [ "Misc", "setup/misc", false, "MiscSetupHandler"],
+          [ "Editor", "setup/editor", false, "EditorSetupHandler"], 
           
           [ "Admin", "admin", true, "AdminHandler"], 
           [ "Password", "admin/password", false, "PasswordAdminHandler"],
@@ -38,7 +58,28 @@ end
          ]
 
 
-def handle_request( cgi)
+def handle_error( cgi, exception)
+
+  output = ""
+
+  output += cgi.h2 { "APRS4R-Fehler/Error" } 
+
+  output += cgi.p { "Es ist ein Fehler aufgetreten. Bitte keine Umlaute oder Sonderzeichen verwenden. " }
+  output += cgi.p { "An error has occurred, please do not use umlauts or other non-ascii characters. " }
+  
+  output += cgi.h3 { "Fehlerausgabe" }
+  
+  if exception.nil?
+    output += cgi.small { cgi.small { "nicht verf&uuml;gbar" } }
+  else
+    output += cgi.small { cgi.small { cgi.pre { exception.backtrace.join( "\n") } } }
+  end
+
+  output
+end
+
+
+def handle_request( cgi, error, exception)
 
   query_string = ENV['QUERY_STRING']
   script_name = ENV['SCRIPT_NAME']
@@ -137,7 +178,16 @@ def handle_request( cgi)
           
           cgi.td( "ALIGN" => "left", "VALIGN" => "top", "WIDTH" => "800") { 
             if handler 
-              output = handler.handle_request( cgi)
+
+              if error 
+                output = handle_error( cgi, exception)
+              else
+                begin
+                  output = handler.handle_request( cgi)
+                rescue Exception => ex
+                  output = handle_error( cgi, ex)
+                end
+              end
             else
               output = "test"
             end
@@ -153,11 +203,31 @@ def handle_request( cgi)
 end
 
 # main loop
-cgi = CGI.new( "html4")
-
-cgi.out { 
-  CGI.pretty( handle_request( cgi))
-}
+cgi = nil
 
+begin
+  begin 
+    cgi = CGI.new( "html4")
+    
+    cgi.out { 
+      handle_request( cgi, false, nil)
+    }
+  rescue Exception => ex
+    ENV['REQUEST_METHOD'] = ""
+    cgi = CGI.new( "html4")
+    
+    cgi.out { 
+      handle_request( cgi, true, ex)
+    }
+  end
+rescue Exception => ex
+  puts "<h1>ERROR</h1>"
+  puts "<pre>"
+  puts ex
+  puts "</pre>"
+  puts "<pre>"
+  ex.backtrace.join( '\n')
+  puts "</pre>"
+end
 
 
