@@ -1,3 +1,21 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
 
@@ -43,12 +61,12 @@ class APRS4WEBSetupHandler
       File.open( etc_dir + "/" + "aprs4web.js").each{ |line|
 
         # parse google key
-        if line =~ /var google_key = \"[A-Za-z0-9\-]*\";/
-          google_key = /var google_key = \"([A-Za-z0-9\-]*)\";/.match( line)[1]
-        elsif line =~ /var my_latitude = [0-9\.]*;/
-          my_latitude = /var my_latitude = ([0-9\.]*);/.match( line)[1]
-        elsif line =~ /var my_longitude = [0-9\.]*;/
-          my_longitude = /var my_longitude = ([0-9\.]*);/.match( line)[1]
+        if line =~ /var google_key = \"[^\"]+\";/
+          google_key = /var google_key = \"([^\"]+)\";/.match( line)[1]
+        elsif line =~ /var my_latitude = [0-9\.]+;/
+          my_latitude = /var my_latitude = ([0-9\.]+);/.match( line)[1]
+        elsif line =~ /var my_longitude = [0-9\.]+;/
+          my_longitude = /var my_longitude = ([0-9\.]+);/.match( line)[1]
         end
       }
     rescue Exception => ex
@@ -100,7 +118,7 @@ class APRS4WEBSetupHandler
 
         cgi.tr { 
           cgi.td( "WIDTH" => "200") { 
-            cgi.big { "Schlssel: " } 
+            cgi.big { "Schl&uuml;ssel: " } 
           } + 
           cgi.td( "WIDTH" => "200") { 
             cgi.text_field( "google_key", google_key.to_s, 40)
@@ -109,13 +127,12 @@ class APRS4WEBSetupHandler
 
         cgi.tr { 
           cgi.td( "COLSPAN" => "2") { 
-            "Zur Benutzung von APRS4WEB ist ein Google Account sowie ein Schlssel fr das Google Maps API notwendig. Beides erhlt man auf folgender Webseite: " + 
+            "Zur Benutzung von APRS4WEB ist ein Google Account sowie ein Schl&uuml;ssel f&uuml;r das Google Maps API notwendig. Beides erh&auml;lt man auf folgender Webseite: " + 
             cgi.a( "http://code.google.com/apis/maps/signup.html") { "http://code.google.com/apis/maps/signup.html" } + cgi.br + cgi.br + 
 
-            "Die URL fr den der Schlssel erzeugt wird, sollte wie folgt aussehen: " + 
+            "Die URL f&uuml;r den der Schl&uuml;ssel erzeugt wird, sollte wie folgt aussehen: " + 
             cgi.b { "http://NAME_ODER_IP_ROUTER/aprs4web/" } + cgi.br + cgi.br +
-
-            "Wird DynDns oder hnliches benutzt kann auch der DNS-Name verwendet werden, z.B. http://meinRouter.dyndns.org/aprs4web."
+            "Wird DynDns oder &auml;hnliches benutzt kann auch der DNS-Name verwendet werden, z.B. http://meinRouter.dyndns.org/aprs4web."
           }
         } + 
 
@@ -137,7 +154,7 @@ class APRS4WEBSetupHandler
 
         cgi.tr { 
           cgi.td( "WIDTH" => "200") { 
-            cgi.big { "Lnge: " } 
+            cgi.big { "L&auml;nge: " } 
           } + 
           cgi.td( "WIDTH" => "200") { 
             cgi.text_field( "my_longitude", my_longitude.to_s, 20)
