@@ -1,3 +1,21 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
 
@@ -40,8 +58,8 @@ class AbstractHandler
 
     parameter = cgi.params[name]
     
-    if parameter 
-      value = parameter[0]
+    if !parameter.nil? && !parameter.empty?
+      value = parameter[0].force_encoding( "ASCII-8BIT")
     end
 
     return value
@@ -52,8 +70,8 @@ class AbstractHandler
     @@logger.info( "show_timeout( cgi)")
 
     return cgi.h3( "ALIGN" => "center", "STYLE" => "color:red") { 
-      "Kein Profil geladen oder Zeitberschreitung!" + 
-      cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { "Hier laden." }
+      "Kein Profil geladen oder Zeit&uuml;berschreitung! " + 
+      cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { " Hier laden." }
     } 
   end
 
@@ -354,7 +372,7 @@ class AbstractHandler
       
       if !sub_form
         attribute_output += cgi.tr { cgi.td { } + cgi.td( "ALIGN" => "right") { 
-            cgi.hidden( "id", item_id.to_s) + cgi.hidden( "plugin", configuration.name) + cgi.submit( "bernehmen", "update") + cgi.submit( "Lschen", "delete")
+            cgi.hidden( "id", item_id.to_s) + cgi.hidden( "plugin", configuration.name) + cgi.submit( "Uebernehmen", "update") + cgi.submit( "Loeschen", "delete")
           }
           
         }
@@ -379,10 +397,12 @@ class AbstractHandler
     begin
       session = YAML.load_file( "/tmp/aprs4r-web-session.yaml")
     rescue Exception => ex
-      # create new session
-      session = Hash.new
+      session = nil
     end
 
+    # create new session
+    session = Hash.new if !session.is_a? Hash
+
     @@logger.debug( "session: #{session.class}, #{session}")
 
     timestamp = Time.now
