@@ -1,3 +1,21 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
 
@@ -36,12 +54,7 @@ class BeaconSetupHandler < AbstractHandler
     configuration = nil
     configuration = session['config'] if session
 
-    if configuration.nil?
-      return cgi.h3( "ALIGN" => "center", "STYLE" => "color:red") { 
-        "Kein Profil geladen oder Zeitberschreitung!" + 
-        cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { "Hier laden." }
-      } 
-    end
+    return show_timeout( cgi) if configuration.nil?
 
     if configuration.plugins.nil?
       configuration.plugins = Hash.new
@@ -55,7 +68,7 @@ class BeaconSetupHandler < AbstractHandler
     if plugins && ! plugins.empty?
       plugins.each{ |id, plugin|
         @@logger.debug( "plugin: #{plugin}, class: #{plugin.class}")
-        if plugin.type =~ /BeaconPlugin/
+        if plugin.type =~ /BeaconPlugin$/
           beacons[id] = plugin
           plugins.delete( id)
         end
@@ -89,12 +102,9 @@ class BeaconSetupHandler < AbstractHandler
     # generate html output
     output = "" 
 
-    if session['changed']
-      output += cgi.h3( "ALIGN" => "right", "STYLE" => "color:red") { 
-        "Achtung: Profil noch nicht gespeichert !" +
-        cgi.a( "/aprs4r-web/cgi-bin/admin.rb/setup") { "Hier speichern." }
-      } 
-    end
+    output += show_profile( cgi, session)
+
+    output += show_changed( cgi, session)
 
     output += create_output( cgi, "Baken", beacons, "Bake", beacon_types, "/aprs4r-web/cgi-bin/admin.rb/setup/beacons")
 
