@@ -1,5 +1,24 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
+require 'aprs4r/APRS4RConfiguration'
 
 include APRS4R
 
@@ -48,17 +67,25 @@ class ProfileStatusHandler
       upload = cgi_parameter( cgi, 'file')
 
       @@logger.debug( "upload.class: #{upload.class}")
+      # @@logger.debug( "upload: #{upload.extract}")
       @@logger.debug( "upload.local_path: #{upload.local_path}")
       @@logger.debug( "upload.original_filename: #{upload.original_filename}")
+      @@logger.debug( "upload.content_type: #{upload.content_type}")
       
-      if !upload.nil? && (upload.length > 0)
+      if !upload.nil? 
         begin
           config_file = File.basename( upload.original_filename) if upload.original_filename
 
           if !config_file.nil?
             File.open( etc_dir + "/" + config_file, "w") { |file|
-              file.puts( upload.read)
+              if upload.respond_to?( :extract)
+                file.puts( upload.extract.read)
+              elsif upload.respond_to?( :read)
+                file.puts( upload.read)
+              end
             }
+
+            APRS4RConfiguration.update_configuration( etc_dir + "/" + config_file)
           end
 
         rescue Exception => ex
@@ -141,13 +168,13 @@ class ProfileStatusHandler
       cgi.tr { 
         cgi.form( "ACTION" => "/aprs4r-web/cgi-bin/admin.rb/status/profile") { 
           cgi.td( "WIDTH" => "200") { 
-            cgi.big { "Profil lschen: " }
+            cgi.big { "Profil l&ouml;schen: " }
           } + 
           cgi.td( "WIDTH" => "200") { 
             cgi.popup_menu( "NAME" => "file", "VALUES" => config_files) 
           } + 
           cgi.td { 
-            cgi.submit( "Lschen", "delete")
+            cgi.submit( "Loeschen", "delete")
           }
         }
       }
