@@ -1,5 +1,21 @@
-
-require 'ftools'
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
 require 'aprs4r/APRS4RConfiguration'
@@ -112,7 +128,7 @@ class SetupHandler < AbstractHandler
     }
 
     if config_file.nil? || config_file.empty?
-      # config_file = "nicht ausgewhlt"
+      # config_file = "nicht ausgew&auml;hlt"
     end
 
 
