@@ -1,3 +1,21 @@
+#
+#  APRS4R - a ruby based aprs gateway/digipeater
+#  Copyright (C) 2011 by Michael Conrad <do5mc at aprs4r.org>
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+#
 
 require 'aprs4r/APRS4RLogger'
 
@@ -242,24 +260,27 @@ class StartupStatusHandler
 
 
     # memory
-    memory_options = [ [ "12288", "12MB"], ["16384", "16MB", true], ["32768", "32MB"], ["65536", "64MB"] ]
+    memory_default = true
+    memory_options = [ ["16384", "16MB"], ["20480", "20MB"], ["24576", "24MB"], ["28672", "28MB"], ["32768", "32MB"], ["65536", "64MB"] ]
     begin
       File.new( default_file).each{ |line|
         if line =~ /ULIMIT="(.*)"/
-          if $1 == "12288"
-            memory_options = [ [ "12288", "12MB", true], ["16384", "16MB"], ["32768", "32MB"], ["65536", "64MB"] ]
-          end
-          if $1 == "32768"
-            memory_options = [ [ "12288", "12MB"], ["16384", "16MB"], ["32768", "32MB", true], ["65536", "64MB"] ]
-          end
-          if $1 == "65536"
-            memory_options = [ [ "12288", "12MB"], ["16384", "16MB"], ["32768", "32MB"], ["65536", "64MB", true] ]
-          end
+          memory_options.each { |option|
+            if option[0] == $1 && option.length == 2
+              option << true
+              memory_default = false
+            end
+          }
         end
       }
     rescue Exception
     end
 
+    # if no limit is set, use 24MB as default
+    if memory_default == true
+      memory_options[2] << true
+    end
+
 
     # watchdog
     watchdog_options = [ [ "true", "ja"], ["false", "nein", true] ]
